@@ -1,21 +1,25 @@
-/* Evolution calendar - Send calendar component dialog
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- * Author: JP Rosevear <jpr@ximian.com>
+/*
+ * Evolution calendar - Send calendar component dialog
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		JP Rosevear <jpr@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,7 +28,6 @@
 
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-uidefs.h>
-#include <e-util/e-icon-factory.h>
 #include "changed-comp.h"
 
 
@@ -48,7 +51,6 @@ changed_component_dialog (GtkWindow *parent, ECalComponent *comp, gboolean delet
 	ECalComponentVType vtype;
 	char *str;
 	gint response;
-	GList *icon_list;
 
 	vtype = e_cal_component_get_vtype (comp);
 
@@ -105,12 +107,7 @@ changed_component_dialog (GtkWindow *parent, ECalComponent *comp, gboolean delet
 					 GTK_MESSAGE_QUESTION,
 					 GTK_BUTTONS_YES_NO, "%s", str);
 
-	icon_list = e_icon_factory_get_icon_list ("stock_calendar");
-	if (icon_list) {
-		gtk_window_set_icon_list (GTK_WINDOW (dialog), icon_list);
-		g_list_foreach (icon_list, (GFunc) g_object_unref, NULL);
-		g_list_free (icon_list);
-	}
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "x-office-calendar");
 
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
