@@ -1,24 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
- * Author :
- *  Rodrigo Moya <rodrigo@ximian.com>
- *
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Rodrigo Moya <rodrigo@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
  */
 
 #ifdef HAVE_CONFIG_H
@@ -81,7 +80,6 @@ static void e_calendar_view_set_property (GObject *object, guint property_id, co
 static void e_calendar_view_destroy (GtkObject *object);
 static void open_event_with_flags (ECalendarView *cal_view, ECal *client, icalcomponent *icalcomp, guint32 flags);
 
-static GdkAtom clipboard_atom = GDK_NONE;
 extern ECompEditorRegistry *comp_editor_registry;
 
 /* Property IDs */
@@ -107,6 +105,17 @@ static guint e_calendar_view_signals[LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (ECalendarView, e_calendar_view, GTK_TYPE_TABLE)
 
+enum TargetType{
+	TARGET_TYPE_VCALENDAR
+};
+
+static GtkTargetEntry target_types[] = {
+	{ "text/x-calendar", 0, TARGET_TYPE_VCALENDAR },
+	{ "text/calendar",   0, TARGET_TYPE_VCALENDAR }
+};
+
+static guint n_target_types = G_N_ELEMENTS (target_types);
+
 static void
 e_calendar_view_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec)
 {
@@ -166,6 +175,7 @@ e_calendar_view_class_init (ECalendarViewClass *klass)
 	klass->get_visible_time_range = NULL;
 	klass->update_query = NULL;
 	klass->open_event = e_calendar_view_open_event;
+	klass->paste_text = NULL;
 
 	g_object_class_install_property (gobject_class, PROP_MODEL,
 					 g_param_spec_object ("model", NULL, NULL, E_TYPE_CAL_MODEL,
@@ -235,11 +245,6 @@ e_calendar_view_class_init (ECalendarViewClass *klass)
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
 
-	/* clipboard atom */
-	if (!clipboard_atom)
-		clipboard_atom = gdk_atom_intern ("CLIPBOARD", FALSE);
-
-
         /*
          * Key bindings
          */
@@ -712,6 +717,34 @@ e_calendar_view_cut_clipboard (ECalendarView *cal_view)
 	g_list_free (selected);
 }
 
+static void
+clipboard_clear_calendar_cb (GtkClipboard *clipboard,
+			     gpointer data)
+{
+	g_free (data);
+}
+
+static void
+clipboard_get_calendar_cb (GtkClipboard *clipboard,
+			   GtkSelectionData *selection_data,
+			   guint info,
+			   gpointer data)
+{
+	gchar *comp_str = (gchar *) data;
+
+	switch (info) {
+	case TARGET_TYPE_VCALENDAR:
+		gtk_selection_data_set (selection_data,
+					selection_data->target,
+					8,
+					(const guchar *) comp_str,
+					(gint) strlen (comp_str));
+		break;
+	default:
+		break;
+	}
+}
+
 void
 e_calendar_view_copy_clipboard (ECalendarView *cal_view)
 {
@@ -720,6 +753,7 @@ e_calendar_view_copy_clipboard (ECalendarView *cal_view)
 	icalcomponent *vcal_comp;
 	icalcomponent *new_icalcomp;
 	ECalendarViewEvent *event;
+	GtkClipboard *clipboard;
 
 	g_return_if_fail (E_IS_CALENDAR_VIEW (cal_view));
 
@@ -753,19 +787,25 @@ e_calendar_view_copy_clipboard (ECalendarView *cal_view)
 	}
 
 	/* copy the VCALENDAR to the clipboard */
+	clipboard = gtk_widget_get_clipboard (GTK_WIDGET (cal_view), GDK_SELECTION_CLIPBOARD);
 	comp_str = icalcomponent_as_ical_string (vcal_comp);
-	gtk_clipboard_set_text (gtk_widget_get_clipboard (GTK_WIDGET (cal_view), clipboard_atom),
-				(const gchar *) comp_str,
-				strlen (comp_str));
+
+	if (!gtk_clipboard_set_with_data (clipboard, target_types, n_target_types,
+					  clipboard_get_calendar_cb,
+					  clipboard_clear_calendar_cb,
+					  comp_str)) {
+		g_free (comp_str);
+	} else {
+		gtk_clipboard_set_can_store (clipboard, target_types + 1, n_target_types - 1);
+	}
 
 	/* free memory */
 	icalcomponent_free (vcal_comp);
-	g_free (comp_str);
 	g_list_free (selected);
 }
 
 static void
-clipboard_get_text_cb (GtkClipboard *clipboard, const gchar *text, ECalendarView *cal_view)
+clipboard_get_calendar_data (ECalendarView *cal_view, const gchar *text)
 {
 	icalcomponent *icalcomp;
 	icalcomponent_kind kind;
@@ -841,13 +881,48 @@ clipboard_get_text_cb (GtkClipboard *clipboard, const gchar *text, ECalendarView
 	e_calendar_view_set_status_message (cal_view, NULL, -1);
 }
 
-void
-e_calendar_view_paste_clipboard (ECalendarView *cal_view)
+static void
+e_calendar_view_paste_text (ECalendarView *cal_view)
 {
 	g_return_if_fail (E_IS_CALENDAR_VIEW (cal_view));
 
-	gtk_clipboard_request_text (gtk_widget_get_clipboard (GTK_WIDGET (cal_view), clipboard_atom),
-				    (GtkClipboardTextReceivedFunc) clipboard_get_text_cb, cal_view);
+	if (E_CALENDAR_VIEW_CLASS (G_OBJECT_GET_CLASS (cal_view))->paste_text)
+		E_CALENDAR_VIEW_CLASS (G_OBJECT_GET_CLASS (cal_view))->paste_text (cal_view);
+}
+
+static void
+clipboard_paste_received_cb (GtkClipboard *clipboard,
+			     GtkSelectionData *selection_data,
+			     gpointer data)
+{
+	if (gtk_clipboard_wait_is_text_available (clipboard)) {
+		e_calendar_view_paste_text (E_CALENDAR_VIEW (data));
+	} else {
+		GdkAtom type = selection_data->type;
+		if (type == gdk_atom_intern (target_types[TARGET_TYPE_VCALENDAR].target, TRUE)) {
+			gchar *result = NULL;
+			result = g_strndup ((const gchar *) selection_data->data,
+					    selection_data->length);
+			clipboard_get_calendar_data (E_CALENDAR_VIEW (data), result);
+			g_free (result);
+		}
+	}
+	g_object_unref (data);
+}
+
+void
+e_calendar_view_paste_clipboard (ECalendarView *cal_view)
+{
+	GtkClipboard *clipboard;
+
+	g_return_if_fail (E_IS_CALENDAR_VIEW (cal_view));
+
+	clipboard = gtk_widget_get_clipboard (GTK_WIDGET (cal_view), GDK_SELECTION_CLIPBOARD);
+	g_object_ref (cal_view);
+
+	gtk_clipboard_request_contents (clipboard,
+					gdk_atom_intern (target_types[TARGET_TYPE_VCALENDAR].target, FALSE),
+					clipboard_paste_received_cb, cal_view);
 }
 
 static void
@@ -2132,6 +2207,83 @@ e_calendar_view_move_tip (GtkWidget *widget, int x, int y)
   gtk_widget_show (widget);
 }
 
+/**
+ * Returns information about attendees in the component. If no attendees, then returns NULL.
+ * The information is like "Status: Accepted: X   Declined: Y  ...".
+ * Free returned pointer with g_free.
+ **/
+char *
+e_calendar_view_get_attendees_status_info (ECalComponent *comp)
+{
+	struct _values {
+		icalparameter_partstat status;
+		const char *caption;
+		int count;
+	} values[] = {
+		{ ICAL_PARTSTAT_ACCEPTED,    N_("Accepted"),     0 },
+		{ ICAL_PARTSTAT_DECLINED,    N_("Declined"),     0 },
+		{ ICAL_PARTSTAT_TENTATIVE,   N_("Tentative"),    0 },
+		{ ICAL_PARTSTAT_DELEGATED,   N_("Delegated"),    0 },
+		{ ICAL_PARTSTAT_NEEDSACTION, N_("Needs action"), 0 },
+		{ ICAL_PARTSTAT_NONE,        N_("Other"),        0 },
+		{ ICAL_PARTSTAT_X,           NULL,              -1 }
+	};
+
+	GSList *attendees = NULL, *a;
+	gboolean have = FALSE;
+	char *res = NULL;
+	int i;
+
+	if (!comp || !e_cal_component_has_attendees (comp))
+		return NULL;
+
+	e_cal_component_get_attendee_list (comp, &attendees);
+
+	for (a = attendees; a; a = a->next) {
+		ECalComponentAttendee *att = a->data;
+
+		if (att && att->cutype == ICAL_CUTYPE_INDIVIDUAL &&
+		    (att->role == ICAL_ROLE_CHAIR ||
+		     att->role == ICAL_ROLE_REQPARTICIPANT ||
+		     att->role == ICAL_ROLE_OPTPARTICIPANT)) {
+			have = TRUE;
+
+			for (i = 0; values[i].count != -1; i++) {
+				if (att->status == values[i].status || values[i].status == ICAL_PARTSTAT_NONE) {
+					values[i].count++;
+					break;
+				}
+			}
+		}
+	}
+
+	if (have) {
+		GString *str = g_string_new ("");
+
+		for (i = 0; values[i].count != -1; i++) {
+			if (values[i].count > 0) {
+				if (str->str && *str->str)
+					g_string_append (str, "   ");
+
+				g_string_append_printf (str, "%s: %d", _(values[i].caption), values[i].count);
+			}
+		}
+
+		g_string_prepend (str, ": ");
+
+		/* To Translators: 'Status' here means the state of the attendees, the resulting string will be in a form:
+		   Status: Accepted: X   Declined: Y   ... */
+		g_string_prepend (str, _("Status"));
+
+		res = g_string_free (str, FALSE);
+	}
+
+	if (attendees)
+		e_cal_component_free_attendee_list (attendees);
+
+	return res;
+}
+
 /*
  * It is expected to show the tooltips in this below format
  *
@@ -2139,6 +2291,7 @@ e_calendar_view_move_tip (GtkWidget *widget, int x, int y)
  * 	Organiser: NameOfTheUser<email@ofuser.com>
  * 	Location: PlaceOfTheMeeting
  * 	Time : DateAndTime (xx Minutes)
+ *      Status: Accepted: X   Declined: Y   ...
  */
 
 gboolean
@@ -2277,6 +2430,17 @@ e_calendar_view_get_tooltips (ECalendarViewEventData *data)
 	g_free (tmp2);
 	g_free (tmp1);
 
+	tmp = e_calendar_view_get_attendees_status_info (newcomp);
+	if (tmp) {
+		hbox = gtk_hbox_new (FALSE, 0);
+		gtk_box_pack_start ((GtkBox *)hbox, gtk_label_new (tmp), FALSE, FALSE, 0);
+		ebox = gtk_event_box_new ();
+		gtk_container_add ((GtkContainer *)ebox, hbox);
+		gtk_box_pack_start ((GtkBox *)box, ebox, FALSE, FALSE, 0);
+
+		g_free (tmp);
+	}
+
 	pevent->tooltip = gtk_window_new (GTK_WINDOW_POPUP);
 	frame = gtk_frame_new (NULL);
 	gtk_frame_set_shadow_type ((GtkFrame *)frame, GTK_SHADOW_IN);
@@ -2412,3 +2576,36 @@ draw_curved_rectangle (cairo_t *cr, double x0, double y0,
 	}
 	cairo_close_path (cr);
 }
+
+static void 
+error_response(GtkWidget *widget, gint response, void *data)
+{
+	if (response == GTK_RESPONSE_DELETE_EVENT) 
+		gtk_widget_destroy(widget);
+	else if (response == GTK_RESPONSE_OK) 
+		gtk_widget_destroy(widget);
+}
+
+void
+e_calendar_utils_show_error_silent (GtkWidget *widget)
+{
+	EActivityHandler *handler = calendar_component_peek_activity_handler (calendar_component_peek ());
+
+	if(!g_object_get_data ((GObject *) widget, "response-handled")) {
+		g_signal_connect(widget, "response", G_CALLBACK(error_response), NULL);
+	}
+
+	e_activity_handler_make_error (handler, "calendar", E_LOG_ERROR, widget);
+}
+
+void
+e_calendar_utils_show_info_silent (GtkWidget *widget)
+{
+	EActivityHandler *handler = calendar_component_peek_activity_handler (calendar_component_peek ());
+
+	if(!g_object_get_data ((GObject *) widget, "response-handled")) {
+		g_signal_connect(widget, "response", G_CALLBACK(error_response), NULL);
+	}
+
+	e_activity_handler_make_error (handler, "calendar", E_LOG_WARNINGS, widget);
+}
