@@ -1,24 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-
 /*
- * Author :
- *  Damon Chaplin <damon@ximian.com>
- *
- * Copyright 1999, Ximian, Inc.
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Damon Chaplin <damon@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
- * USA
  */
 
 /*
@@ -34,12 +33,14 @@
 #include "e-util/e-categories-config.h"
 #include <libecal/e-cal-time-util.h>
 #include <libedataserver/e-data-server-util.h>
+#include <libedataserver/e-categories.h>
 #include "e-calendar-view.h"
 #include "e-day-view-top-item.h"
 
-static void e_day_view_top_item_set_arg		(GtkObject	 *o,
-						 GtkArg		 *arg,
-						 guint		  arg_id);
+static void e_day_view_top_item_set_property	(GObject	 *object,
+						 guint		  property_id,
+						 const GValue	 *value,
+						 GParamSpec	 *pspec);
 static void e_day_view_top_item_update		(GnomeCanvasItem *item,
 						 double		 *affine,
 						 ArtSVP		 *clip_path,
@@ -76,9 +77,9 @@ static gint e_day_view_top_item_event		(GnomeCanvasItem *item,
 
 /* The arguments we take */
 enum {
-	ARG_0,
-	ARG_DAY_VIEW,
-	ARG_SHOW_DATES
+	PROP_0,
+	PROP_DAY_VIEW,
+	PROP_SHOW_DATES
 };
 
 G_DEFINE_TYPE (EDayViewTopItem, e_day_view_top_item, GNOME_TYPE_CANVAS_ITEM)
@@ -86,27 +87,36 @@ G_DEFINE_TYPE (EDayViewTopItem, e_day_view_top_item, GNOME_TYPE_CANVAS_ITEM)
 static void
 e_day_view_top_item_class_init (EDayViewTopItemClass *class)
 {
-	GtkObjectClass  *object_class;
+	GObjectClass  *object_class;
 	GnomeCanvasItemClass *item_class;
 
-	object_class = (GtkObjectClass *) class;
-	item_class = (GnomeCanvasItemClass *) class;
+	object_class = G_OBJECT_CLASS (class);
+	object_class->set_property = e_day_view_top_item_set_property;
 
-	gtk_object_add_arg_type ("EDayViewTopItem::day_view",
-				 GTK_TYPE_POINTER, GTK_ARG_WRITABLE,
-				 ARG_DAY_VIEW);
+	item_class = GNOME_CANVAS_ITEM_CLASS (class);
+	item_class->update = e_day_view_top_item_update;
+	item_class->draw = e_day_view_top_item_draw;
+	item_class->point = e_day_view_top_item_point;
+	item_class->event = e_day_view_top_item_event;
 
-	gtk_object_add_arg_type ("EDayViewTopItem::show_dates",
-				 GTK_TYPE_BOOL, GTK_ARG_WRITABLE,
-				 ARG_SHOW_DATES);
+	g_object_class_install_property (
+		object_class,
+		PROP_DAY_VIEW,
+		g_param_spec_pointer (
+			"day_view",
+			NULL,
+			NULL,
+			G_PARAM_WRITABLE));
 
-	object_class->set_arg = e_day_view_top_item_set_arg;
-
-	/* GnomeCanvasItem method overrides */
-	item_class->update      = e_day_view_top_item_update;
-	item_class->draw        = e_day_view_top_item_draw;
-	item_class->point       = e_day_view_top_item_point;
-	item_class->event       = e_day_view_top_item_event;
+	g_object_class_install_property (
+		object_class,
+		PROP_SHOW_DATES,
+		g_param_spec_boolean (
+			"show_dates",
+			NULL,
+			NULL,
+			TRUE,
+			G_PARAM_WRITABLE));
 }
 
 
@@ -119,20 +129,25 @@ e_day_view_top_item_init (EDayViewTopItem *dvtitem)
 
 
 static void
-e_day_view_top_item_set_arg (GtkObject *o, GtkArg *arg, guint arg_id)
+e_day_view_top_item_set_property (GObject *object,
+                                  guint property_id,
+                                  const GValue *value,
+                                  GParamSpec *pspec)
 {
 	EDayViewTopItem *dvtitem;
 
-	dvtitem = E_DAY_VIEW_TOP_ITEM (o);
+	dvtitem = E_DAY_VIEW_TOP_ITEM (object);
 
-	switch (arg_id){
-	case ARG_DAY_VIEW:
-		dvtitem->day_view = GTK_VALUE_POINTER (*arg);
-		break;
-	case ARG_SHOW_DATES:
-		dvtitem->show_dates = GTK_VALUE_BOOL (*arg);
-		break;
+	switch (property_id) {
+	case PROP_DAY_VIEW:
+		dvtitem->day_view = g_value_get_pointer (value);
+		return;
+	case PROP_SHOW_DATES:
+		dvtitem->show_dates = g_value_get_boolean (value);
+		return;
 	}
+
+	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 }
 
 
@@ -673,29 +688,28 @@ e_day_view_top_item_draw_long_event (EDayViewTopItem *dvtitem,
 	e_cal_component_get_categories_list (comp, &categories_list);
 	for (elem = categories_list; elem; elem = elem->next) {
 		char *category;
-		GdkPixmap *pixmap = NULL;
-		GdkBitmap *mask = NULL;
+		const char *file;
+		GdkPixbuf *pixbuf;
 
 		category = (char *) elem->data;
-		e_categories_config_get_icon_for (category, &pixmap, &mask);
-		if (pixmap == NULL)
+		file = e_categories_get_icon_file_for (category);
+		if (!file)
+			continue;
+
+		pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+		if (pixbuf == NULL)
 			continue;
 
 		if (icon_x <= max_icon_x) {
 			gdk_gc_set_clip_origin (gc, icon_x, icon_y);
-			if (mask != NULL)
-				gdk_gc_set_clip_mask (gc, mask);
-			gdk_draw_drawable (drawable, gc,
-					 pixmap,
+			gdk_draw_pixbuf (drawable, gc,
+					 pixbuf,
 					 0, 0, icon_x, icon_y,
 					 E_DAY_VIEW_ICON_WIDTH,
-					 E_DAY_VIEW_ICON_HEIGHT);
+					 E_DAY_VIEW_ICON_HEIGHT,
+					 GDK_RGB_DITHER_NORMAL, 0, 0);
 			icon_x -= icon_x_inc;
 		}
-
-		g_object_unref (pixmap);
-		if (mask != NULL)
-			g_object_unref (mask);
 	}
 
 	e_cal_component_free_categories_list (categories_list);
