@@ -1,26 +1,26 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- *
- *  Authors: Not Zed <notzed@lostzed.mmc.com.au>
- *           Jeffrey Stedfast <fejj@ximian.com>
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Not Zed <notzed@lostzed.mmc.com.au>
+ *      Jeffrey Stedfast <fejj@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -43,6 +43,7 @@ static void set_source (RuleEditor *re, const char *source);
 static void set_sensitive (RuleEditor *re);
 static FilterRule *create_rule (RuleEditor *re);
 
+static gboolean update_selected_rule (RuleEditor *re);
 static void cursor_changed (GtkTreeView *treeview, RuleEditor *re);
 
 static void rule_editor_class_init (RuleEditorClass *klass);
@@ -442,6 +443,8 @@ rule_edit (GtkWidget *widget, RuleEditor *re)
 {
 	GtkWidget *rules;
 
+	update_selected_rule(re);
+
 	if (re->current == NULL || re->edit != NULL)
 		return;
 
@@ -483,6 +486,8 @@ rule_delete (GtkWidget *widget, RuleEditor *re)
 	GtkTreeIter iter;
 	int pos, len;
 
+	update_selected_rule(re);
+
 	d(printf ("delete rule\n"));
 	pos = rule_context_get_rank_rule (re->context, re->current, re->source);
 	if (pos != -1) {
@@ -576,6 +581,8 @@ rule_top (GtkWidget *widget, RuleEditor *re)
 {
 	int pos;
 
+	update_selected_rule(re);
+
 	d(printf ("top rule\n"));
 	pos = rule_context_get_rank_rule (re->context, re->current, re->source);
 	if (pos > 0)
@@ -587,6 +594,8 @@ rule_up (GtkWidget *widget, RuleEditor *re)
 {
 	int pos;
 
+	update_selected_rule(re);
+
 	d(printf ("up rule\n"));
 	pos = rule_context_get_rank_rule (re->context, re->current, re->source);
 	if (pos > 0)
@@ -598,6 +607,8 @@ rule_down (GtkWidget *widget, RuleEditor *re)
 {
 	int pos;
 
+	update_selected_rule(re);
+
 	d(printf ("down rule\n"));
 	pos = rule_context_get_rank_rule (re->context, re->current, re->source);
 	if (pos >= 0)
@@ -611,6 +622,8 @@ rule_bottom (GtkWidget *widget, RuleEditor *re)
 	int index = -1, count = 0;
 	FilterRule *rule = NULL;
 
+	update_selected_rule(re);
+
 	d(printf ("bottom rule\n"));
 	pos = rule_context_get_rank_rule (re->context, re->current, re->source);
 	/* There's probably a better/faster way to get the count of the list here */
@@ -669,8 +682,8 @@ dialog_rule_changed (FilterRule *fr, GtkWidget *dialog)
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, fr && fr->parts);
 }
 
-static void
-cursor_changed (GtkTreeView *treeview, RuleEditor *re)
+static gboolean
+update_selected_rule (RuleEditor *re)
 {
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
@@ -679,7 +692,16 @@ cursor_changed (GtkTreeView *treeview, RuleEditor *re)
 	selection = gtk_tree_view_get_selection (re->list);
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
 		gtk_tree_model_get (GTK_TREE_MODEL (re->model), &iter, 1, &re->current, -1);
+		return TRUE;
+	}
 
+	return FALSE;
+}
+
+static void
+cursor_changed (GtkTreeView *treeview, RuleEditor *re)
+{
+	if (update_selected_rule(re)) {
 		g_return_if_fail (re->current);
 
 		rule_editor_set_sensitive (re);
