@@ -1,25 +1,24 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors:
- *    Dan Winship <danw@ximian.com>
- *    Jeffrey Stedfast <fejj@ximian.com>
- *    Michael Zucchi <notzed@ximian.com>
- *
- *  Copyright 2001 Ximian, Inc. (www.ximian.com)
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Dan Winship <danw@ximian.com>
+ *		Jeffrey Stedfast <fejj@ximian.com>
+ *		Michael Zucchi <notzed@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -39,7 +38,7 @@
 #include <config.h>
 #endif
 
-#include <glib.h>
+#include <glib/gi18n.h>
 #include <glib/gstdio.h>
 
 #include <string.h>
@@ -49,22 +48,6 @@
 
 #include <glade/glade.h>
 
-#include <gtk/gtkentry.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtktextbuffer.h>
-#include <gtk/gtktextview.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtktable.h>
-
-#include <glib/gi18n.h>
 #include <libgnomeui/gnome-druid.h>
 #include <libgnomeui/gnome-druid-page-standard.h>
 
@@ -2018,7 +2001,7 @@ emae_option_checkspin(EMAccountEditorService *service, CamelURL *url, const char
 
 	spin = gtk_spin_button_new((GtkAdjustment *)gtk_adjustment_new(def, min, max, 1, 1, 1), 1, 0);
 	if (post)
-		label = gtk_label_new(post);
+		label = gtk_label_new_with_mnemonic(post);
 	gtk_box_pack_start((GtkBox *)hbox, check, FALSE, TRUE, 0);
 	gtk_box_pack_start((GtkBox *)hbox, spin, FALSE, TRUE, 0);
 	if (label)
@@ -2036,6 +2019,96 @@ emae_option_checkspin(EMAccountEditorService *service, CamelURL *url, const char
 	return hbox;
 }
 
+static void
+emae_option_options_changed (GtkComboBox *options, EMAccountEditorService *service)
+{
+	const char *name = g_object_get_data (G_OBJECT (options), "option-name");
+	char *value = NULL;
+	CamelURL *url = emae_account_url (service->emae, emae_service_info[service->type].account_uri_key);
+	int id = gtk_combo_box_get_active (options);
+
+	if (id != -1) {
+		GtkTreeModel *model;
+		GtkTreeIter iter;
+
+		model = gtk_combo_box_get_model (options);
+		if (gtk_tree_model_iter_nth_child (model, &iter, NULL, id)) {
+			gtk_tree_model_get (model, &iter, 0, &value, -1);
+		}
+	}
+
+	camel_url_set_param (url, name, value);
+	emae_uri_changed (service, url);
+	camel_url_free (url);
+	g_free (value);
+}
+
+/* 'values' is in format "value0:caption0:value2:caption2:...valueN:captionN" */
+static GtkWidget *
+emae_option_options (EMAccountEditorService *service, CamelURL *url, const char *name, const char *values, GtkWidget *l)
+{
+	GtkComboBox *w;
+	GtkListStore *store;
+	GtkTreeIter iter;
+	const char *p, *value, *caption;
+	GtkCellRenderer *cell;
+	int active = 0; /* the first item entered is always a default item */
+	int i;
+	const char *val = camel_url_get_param (url, name);
+
+	w = GTK_COMBO_BOX (gtk_combo_box_new ());
+
+	/* value and caption */
+	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
+
+	p = values;
+	for (p = values, i = 0; p; i++) {
+		char *vl, *cp;
+
+		value = p;
+		caption = strchr (p, ':');
+		if (caption) {
+			caption++;
+		} else {
+			g_warning (G_STRLOC ": expected ':' not found at '%s'", p);
+			break;
+		}
+		p = strchr (caption, ':');
+
+		vl = g_strndup (value, caption - value - 1);
+		if (p) {
+			p++;
+			cp = g_strndup (caption, p - caption - 1);
+		} else
+			cp = g_strdup (caption);
+
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter, 0, vl, 1, dgettext (service->provider->translation_domain, cp), -1);
+
+		if (val && g_ascii_strcasecmp (val, vl) == 0)
+			active = i;
+
+		g_free (vl);
+		g_free (cp);
+	}
+
+	gtk_combo_box_set_model (w, (GtkTreeModel *)store);
+	gtk_combo_box_set_active (w, i > 0 ? active : -1);
+
+	cell = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (w), cell, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (w), cell, "text", 1, NULL);
+
+	gtk_widget_show (GTK_WIDGET (w));
+
+	gtk_label_set_mnemonic_widget (GTK_LABEL (l), GTK_WIDGET (w));
+
+	g_object_set_data (G_OBJECT (w), "option-name", (void *)name);
+	g_signal_connect (w, "changed", G_CALLBACK (emae_option_options_changed), service);
+
+	return GTK_WIDGET (w);
+}
+
 static GtkWidget *
 emae_receive_options_item(EConfig *ec, EConfigItem *item, struct _GtkWidget *parent, struct _GtkWidget *old, void *data)
 {
@@ -2078,7 +2151,7 @@ emae_receive_options_extra_item(EConfig *ec, EConfigItem *eitem, struct _GtkWidg
 {
 	EMAccountEditor *emae = data;
 	struct _receive_options_item *item = (struct _receive_options_item *)eitem;
-	GtkWidget *w, *l;
+	GtkWidget *w, *l, *h;
 	CamelProviderConfEntry *entries;
 	GtkWidget *depw;
 	GSList *depl = NULL, *n;
@@ -2167,6 +2240,20 @@ section:
 				depl = g_slist_prepend(depl, w);
 			row++;
 			break;
+		case CAMEL_PROVIDER_CONF_OPTIONS:
+			h = gtk_hbox_new (FALSE, 4);
+			gtk_widget_show (h);
+			l = g_object_new (gtk_label_get_type (), "label", entries[i].text, "xalign", 0.0, "use_underline", TRUE, NULL);
+			gtk_widget_show (l);
+			w = emae_option_options (service, url, entries[i].name, entries[i].value, l);
+			gtk_box_pack_start (GTK_BOX (h), l, FALSE, FALSE, 0);
+			gtk_box_pack_start (GTK_BOX (h), w, FALSE, FALSE, 0);
+			gtk_table_attach ((GtkTable *)parent, h, 0, 2, row, row+1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+			if (depw) {
+				depl = g_slist_prepend (depl, h);
+			}
+			row++;
+			break;
 		default:
 			break;
 		}
