@@ -1,44 +1,32 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * e-search-bar.c
- *
- * Copyright (C) 2000, 2001 Ximian, Inc.
- *
- * Authors:
- *  Chris Lahey      <clahey@ximian.com>
- *  Ettore Perazzoli <ettore@ximian.com>
- *  Jon Trowbridge   <trow@ximian.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ *
+ *
+ * Authors:
+ *		Chris Lahey <clahey@ximian.com>
+ *		Ettore Perazzoli <ettore@ximian.com>
+ *		Jon Trowbridge <trow@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkdrawingarea.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkoptionmenu.h>
-#include <gtk/gtkradiomenuitem.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkversion.h>
 
 #include <misc/e-unicode.h>
 #include <misc/e-gui-utils.h>
@@ -54,7 +42,6 @@
 #include "e-search-bar.h"
 #include "e-util/e-util.h"
 #include "e-util/e-util-marshal.h"
-#include "e-util/e-icon-factory.h"
 
 
 enum {
@@ -215,11 +202,11 @@ search_now_verb_cb (BonoboUIComponent *ui_component,
 		gtk_widget_modify_text (esb->entry, GTK_STATE_NORMAL, &(style->text[GTK_STATE_SELECTED]));
 		gtk_widget_modify_base (esb->icon_entry, GTK_STATE_NORMAL, &(style->base[GTK_STATE_SELECTED]));
 		gtk_widget_modify_base (esb->viewoption, GTK_STATE_NORMAL, &(style->base[GTK_STATE_SELECTED]));
-
 	} else {
 		gtk_widget_modify_base (esb->entry, GTK_STATE_NORMAL, NULL);
 		gtk_widget_modify_text (esb->entry, GTK_STATE_NORMAL, NULL);
 		gtk_widget_modify_base (esb->icon_entry, GTK_STATE_NORMAL, NULL);
+		gtk_widget_set_sensitive (esb->clear_button, FALSE);
 	}
 
 	g_free (text);
@@ -237,6 +224,7 @@ clear_verb_cb (BonoboUIComponent *ui_component,
 	gtk_widget_modify_base (esb->entry, GTK_STATE_NORMAL, NULL);
 	gtk_widget_modify_text (esb->entry, GTK_STATE_NORMAL, NULL);
 	gtk_widget_modify_base (esb->icon_entry, GTK_STATE_NORMAL, NULL);
+	gtk_widget_set_sensitive (esb->clear_button, FALSE);
 
 	clear_search (esb);
 	gtk_entry_set_text (GTK_ENTRY (esb->entry), "");
@@ -347,8 +335,9 @@ paint_search_text (GtkWidget *widget, ESearchBar *esb)
 		}
 
 		t = g_strdup_printf ("%s: %s\n%s", _("Search"), text, _("Click here to change the search type"));
-		gtk_tooltips_set_tip (esb->tooltips, esb->option_button, t, "Search type");
+		gtk_widget_set_tooltip_text (esb->option_button, t);
 		g_free (t);
+
 		gtk_widget_set_sensitive (esb->clear_button, FALSE);
 	}
 
@@ -385,6 +374,7 @@ entry_activated_cb (GtkWidget *widget,
 		gtk_widget_modify_base (esb->entry, GTK_STATE_NORMAL, NULL);
 		gtk_widget_modify_text (esb->entry, GTK_STATE_NORMAL, NULL);
 		gtk_widget_modify_base (esb->icon_entry, GTK_STATE_NORMAL, NULL);
+		gtk_widget_set_sensitive (esb->clear_button, FALSE);
 	}
 
 	emit_search_activated (esb);
@@ -400,13 +390,15 @@ entry_changed_cb (GtkWidget *widget,
 	entry_style = gtk_widget_get_style (esb->entry);
 	default_style = gtk_widget_get_default_style ();
 
-	if (text && *text)
+	if (text && *text) {
 		if (gdk_color_equal (&(entry_style->text[GTK_STATE_NORMAL]), &(default_style->text[GTK_STATE_INSENSITIVE])))
 			gtk_widget_set_sensitive (esb->clear_button, FALSE);
 		else
 			gtk_widget_set_sensitive (esb->clear_button, TRUE);
-	else
-		gtk_widget_set_sensitive (esb->clear_button, FALSE);
+	} else {
+		/* selected color means some search text is active */
+		gtk_widget_set_sensitive (esb->clear_button, gdk_color_equal (&(entry_style->base[GTK_STATE_NORMAL]), &(default_style->base[GTK_STATE_SELECTED])));
+	}
 }
 
 static void
@@ -479,7 +471,7 @@ option_activated_cb (GtkWidget *widget,
 		else
 			t = g_strdup_printf ("%s: %s", _("Search"), _("Click here to change the search type"));
 
-		gtk_tooltips_set_tip (esb->tooltips, esb->option_button, t, "Search type");
+		gtk_widget_set_tooltip_text (esb->option_button, t);
 		g_free (t);
 	}
 
@@ -507,6 +499,7 @@ clear_button_clicked_cb (GtkWidget *widget, GdkEventButton *event,
 	gtk_widget_modify_base (esb->entry, GTK_STATE_NORMAL, NULL);
 	gtk_widget_modify_text (esb->entry, GTK_STATE_NORMAL, NULL);
 	gtk_widget_modify_base (esb->icon_entry, GTK_STATE_NORMAL, NULL);
+	gtk_widget_set_sensitive (esb->clear_button, FALSE);
 
 	clear_search (esb);
 	gtk_entry_set_text (GTK_ENTRY (esb->entry), "");
@@ -938,7 +931,6 @@ init (ESearchBar *esb)
 	esb->scopeoption      = NULL;
 	esb->scopeoption_box  = NULL;
 
-	esb->tooltips         = NULL;
 	esb->pending_activate = 0;
 
 	esb->item_id          = 0;
@@ -974,8 +966,6 @@ e_search_bar_construct (ESearchBar *search_bar,
 
 	gtk_box_set_homogeneous (GTK_BOX (search_bar), FALSE);
 
-	search_bar->tooltips = gtk_tooltips_new ();
-
 	bighbox = gtk_hbox_new (FALSE, 0);
 	search_bar->entry_box = gtk_hbox_new (0, FALSE);
 	search_bar->icon_entry = e_icon_entry_new ();
